@@ -834,7 +834,7 @@ class Product(models.Model):
             return properties
 
         properties = []
-        for ppv in self.property_values.filter(property__display_on_product=True, type=PROPERTY_VALUE_TYPE_DISPLAY).order_by("property__position"):
+        for ppv in self.property_values.filter(property__display_on_product=True, type=PROPERTY_VALUE_TYPE_DISPLAY):
             if ppv.property.is_select_field:
                 try:
                     po = PropertyOption.objects.get(pk=int(float(ppv.value)))
@@ -842,15 +842,21 @@ class Product(models.Model):
                     continue
                 else:
                     value = po.name
+                    position = po.position
             else:
                 value = ppv.value
+                position = 1
+
+            print ppv.property.position
             properties.append({
+                "position": (ppv.property.position * 1000) + position,
                 "name"  : ppv.property.name,
                 "title" : ppv.property.title,
                 "value" : value,
                 "unit"  : ppv.property.unit,
             })
 
+        properties.sort(lambda a, b: cmp(a["position"], b["position"]))
         cache.set(cache_key, properties)
         return properties
 
@@ -1304,7 +1310,7 @@ class Product(models.Model):
         """
         if self.manage_stock_amount and self.stock_amount <= 0 and not self.order_time:
             return False
-        else:    
+        else:
             return self.deliverable
 
     # 3rd party contracts
@@ -1980,4 +1986,4 @@ class DeliveryTime(models.Model):
         min = int("%.0f" % (self.min + 0.001))
         max = int("%.0f" % (self.max + 0.001))
 
-        return DeliveryTime(min=min, max=max, unit=self.unit)
\ No newline at end of file
+        return DeliveryTime(min=min, max=max, unit=self.unit)
