@@ -1,3 +1,7 @@
+# python imports
+import math
+import urllib
+
 # django imports
 from django.conf import settings
 from django.core.cache import cache
@@ -17,13 +21,28 @@ import lfs.core.utils
 from lfs.caching.utils import lfs_get_object_or_404
 from lfs.cart.views import add_to_cart
 from lfs.catalog.models import Category
+from lfs.catalog.models import File
 from lfs.catalog.models import Product
-from lfs.catalog.settings import PRODUCT_WITH_VARIANTS, VARIANT
+from lfs.catalog.models import ProductPropertyValue
+from lfs.catalog.models import PropertyOption
+from lfs.catalog.settings import PRODUCT_WITH_VARIANTS
+from lfs.catalog.settings import VARIANT
+from lfs.catalog.settings import PROPERTY_VALUE_TYPE_DEFAULT
 from lfs.catalog.settings import SELECT
 from lfs.catalog.settings import CONTENT_PRODUCTS
 from lfs.core.utils import LazyEncoder
+from lfs.core.templatetags import lfs_tags
 from lfs.utils import misc as lfs_utils
 
+def file(request, language=None, id=None):
+    """Delivers files to the browser.
+    """
+    file = lfs_get_object_or_404(File, pk=id)
+    response = HttpResponse(file.file, mimetype='application/binary')
+    response['Content-Disposition'] = 'attachment; filename=%s' % file.title
+
+    return response
+
 def select_variant(request):
     """This is called via an ajax call if the combination of properties are
     changed.
@@ -38,15 +57,81 @@ def select_variant(request):
 
     return HttpResponse(result)
 
+def calculate_packing(request, id, quantity=None, as_string=False, template_name="lfs/catalog/packing_result.html"):
+    """Calculates the actual amount of pieces to buy on base on packing
+    information.
+    """
+    product = Product.objects.get(pk = id)
+
+    if quantity is None:
+        quantity = float(request.POST.get("quantity"))
+
+    packing_amount, packing_unit= product.get_packing_info()
+
+    packs = math.ceil(quantity / packing_amount)
+    real_quantity = packs * packing_amount
+    price = real_quantity * product.get_price()
+
+    html = render_to_string(template_name, RequestContext(request, {
+        "price" : price,
+        "product" : product,
+        "packs" : int(packs),
+        "real_quantity" : real_quantity,
+        "unit" : packing_unit,
+    }))
+
+    if as_string:
+        return html
+
+    result = simplejson.dumps({
+        "html" : html,
+    }, cls = LazyEncoder)
+
+    return HttpResponse(result)
+
+def calculate_price(request, id):
+    """Calculates the price of the product on base of choosen properties.
+    """
+    product = Product.objects.get(pk = id)
+
+    property_price = 0
+    for key, option_id in request.POST.items():
+        if key.startswith("property"):
+            try:
+                po = PropertyOption.objects.get(pk=option_id)
+            except (ValueError, PropertyOption.DoesNotExist):
+                pass
+            else:
+                if po.property.add_price:
+                    property_price += po.price
+
+    for_sale_price = product.get_for_sale_price(with_properties=False)
+    for_sale_price += property_price
+
+    for_sale_standard_price = product.get_standard_price(with_properties=False)
+    for_sale_standard_price += property_price
+
+    price = product.get_price(with_properties=False)
+    price += property_price
+
+    result = simplejson.dumps({
+        "price" : lfs_tags.currency(price),
+        "for-sale-price" : lfs_tags.currency(for_sale_price),
+        "for-sale-standard-price" : lfs_tags.currency(for_sale_standard_price),
+        "message" : _("Price has been changed according to your selection."),
+    }, cls = LazyEncoder)
+
+    return HttpResponse(result)
+
 def select_variant_from_properties(request):
     """This is called via an ajax call if the combination of properties are
     changed.
     """
     product_id = request.POST.get("product_id")
-    
+
     try:
         product = Product.objects.get(pk = product_id)
-    except Product.DoesNotExist:
+    except:# Product.DoesNotExist:
         return HttpResponse("")
 
     options = lfs_utils.parse_properties(request)
@@ -78,7 +163,7 @@ def set_filter(request, category_slug, property_id, value=None, min=None, max=No
 
     request.session["product-filter"] = product_filter
 
-    url = reverse("lfs_category", kwargs={"slug" : category_slug, "start" : 0})
+    url = reverse("lfs_category", kwargs={"slug" : category_slug })
     return HttpResponseRedirect(url)
 
 def set_price_filter(request, category_slug):
@@ -100,7 +185,7 @@ def set_price_filter(request, category_slug):
 
     request.session["price-filter"] = {"min" : min, "max": max}
 
-    url = reverse("lfs_category", kwargs={"slug" : category_slug, "start" : 0})
+    url = reverse("lfs_category", kwargs={"slug" : category_slug })
     return HttpResponseRedirect(url)
 
 def reset_price_filter(request, category_slug):
@@ -109,7 +194,7 @@ def reset_price_filter(request, category_slug):
     if request.session.has_key("price-filter"):
         del request.session["price-filter"]
 
-    url = reverse("lfs_category", kwargs={"slug" : category_slug, "start" : 0})
+    url = reverse("lfs_category", kwargs={"slug" : category_slug })
     return HttpResponseRedirect(url)
 
 def reset_filter(request, category_slug, property_id):
@@ -121,7 +206,7 @@ def reset_filter(request, category_slug, property_id):
             del request.session["product-filter"][property_id]
             request.session["product-filter"] = request.session["product-filter"]
 
-    url = reverse("lfs_category", kwargs={"slug" : category_slug, "start" : 0})
+    url = reverse("lfs_category", kwargs={"slug" : category_slug })
     return HttpResponseRedirect(url)
 
 def reset_all_filter(request, category_slug):
@@ -133,7 +218,7 @@ def reset_all_filter(request, category_slug):
     if request.session.has_key("price-filter"):
         del request.session["price-filter"]
 
-    url = reverse("lfs_category", kwargs={"slug" : category_slug, "start" : 0})
+    url = reverse("lfs_category", kwargs={"slug" : category_slug })
     return HttpResponseRedirect(url)
 
 def set_sorting(request):
@@ -148,16 +233,15 @@ def set_sorting(request):
     # lfs_sorting_changed.send(category_id)
     return HttpResponseRedirect(request.META.get("HTTP_REFERER"))
 
-def category_view(request, slug, start=0, template_name="lfs/catalog/category_base.html"):
+def category_view(request, slug, template_name="lfs/catalog/category_base.html"):
     """
     """
+    start = request.REQUEST.get("start", 0)
     category = lfs_get_object_or_404(Category, slug=slug)
-
-    if category.content == CONTENT_PRODUCTS:
+    if category.get_content() == CONTENT_PRODUCTS:
         inline = category_products(request, slug, start)
     else:
         inline = category_categories(request, slug)
-
     # Set last visited category for later use, e.g. Display breadcrumbs,
     # selected menu points, etc.
     request.session["last_category"] = category
@@ -171,10 +255,10 @@ def category_view(request, slug, start=0, template_name="lfs/catalog/category_ba
         "top_category" : lfs.catalog.utils.get_current_top_category(request, category),
     }))
 
-def category_categories(request, slug, template_name="lfs/catalog/category_categories.html"):
+def category_categories(request, slug, start=0, template_name="lfs/catalog/categories/category/default.html"):
     """Displays the child categories of the category with passed slug.
 
-    This is displayed if the category's content attribute is set to categories".
+    This view is called if the user chooses a template that is situated in settings.CATEGORY_PATH ".
     """
     cache_key = "category-categories-%s" % slug
 
@@ -197,6 +281,10 @@ def category_categories(request, slug, template_name="lfs/catalog/category_categ
 
     if len(row) > 0:
         categories.append(row)
+    render_template = category.get_template_name()
+
+    if render_template != None:
+        template_name = render_template
 
     result = render_to_string(template_name, RequestContext(request, {
         "category" : category,
@@ -206,10 +294,10 @@ def category_categories(request, slug, template_name="lfs/catalog/category_categ
     cache.set(cache_key, result)
     return result
 
-def category_products(request, slug, start=0, template_name="lfs/catalog/category_products.html"):
+def category_products(request, slug, start=0, template_name="lfs/catalog/categories/product/default.html"):
     """Displays the products of the category with passed slug.
 
-    This is displayed if the category's content attribute is set to products.
+    This view is called if the user chooses a template that is situated in settings.PRODUCT_PATH ".
     """
     # Resets the product filters if the user navigates to another category.
     # TODO: Is this what a customer would expect?
@@ -220,7 +308,12 @@ def category_products(request, slug, start=0, template_name="lfs/catalog/categor
         if request.session.has_key("price-filter"):
             del request.session["price-filter"]
 
-    sorting = request.session.get("sorting", "price")
+    try:
+        default_sorting = settings.LFS_PRODUCTS_SORTING
+    except AttributeError:
+        default_sorting = "price"
+
+    sorting = request.session.get("sorting", default_sorting)
     product_filter = request.session.get("product-filter", {})
     product_filter = product_filter.items()
 
@@ -249,7 +342,7 @@ def category_products(request, slug, start=0, template_name="lfs/catalog/categor
     # Calculates parameters for display.
     try:
         start = int(start)
-    except ValueError:
+    except (ValueError, TypeError):
         start = 0
 
     format_info = category.get_format_info()
@@ -267,7 +360,14 @@ def category_products(request, slug, start=0, template_name="lfs/catalog/categor
         # Switch to default variant if product is a "product with variants".
         # if product.is_product_with_variants() and product.has_variants():
         #    product = product.get_default_variant()
-        row.append(product)
+        row.append({
+            "obj" : product,
+            "slug" : product.slug,
+            "name" : product.get_name(),
+            "image" : product.get_image(),
+            "price" : product.get_price(),
+            "standard_price" : product.get_standard_price(),
+        })
         if (i+1) % amount_of_cols == 0:
             products.append(row)
             row = []
@@ -288,15 +388,19 @@ def category_products(request, slug, start=0, template_name="lfs/catalog/categor
         })
 
     if (start + amount) < amount_of_products:
-        next_url = "%s/%s" % (category.get_absolute_url(), start + amount)
+        next_url = "%s?start=%s" % (category.get_absolute_url(), start + amount)
     else:
         next_url = None
 
     if (start - amount) >= 0:
-        previous_url = "%s/%s" % (category.get_absolute_url(), start - amount)
+        previous_url = "%s?start=%s" % (category.get_absolute_url(), start - amount)
     else:
         previous_url = None
 
+    render_template = category.get_template_name()
+    if render_template != None:
+        template_name = render_template
+
     result = render_to_string(template_name, RequestContext(request, {
         "category" : category,
         "products" : products,
@@ -305,6 +409,7 @@ def category_products(request, slug, start=0, template_name="lfs/catalog/categor
         "amount_of_products" : amount_of_products,
         "pages" : pages,
         "show_pages" : amount_of_products > amount,
+        "all_products" : all_products
     }))
 
     temp[sub_cache_key] = result
@@ -330,14 +435,15 @@ def product_view(request, slug, template_name="lfs/catalog/product_base.html"):
 
     # TODO: Factor top_category out to a inclusion tag, so that people can
     # omit if they don't need it.
-
-    return render_to_response(template_name, RequestContext(request, {
+    result =  render_to_response(template_name, RequestContext(request, {
         "product_inline" : product_inline(request, product.id),
         "product" : product,
         "top_category" : lfs.catalog.utils.get_current_top_category(request, product),
     }))
 
-def product_inline(request, id, template_name="lfs/catalog/product_inline.html"):
+    return result
+
+def product_inline(request, id, template_name="lfs/catalog/products/product_inline.html"):
     """Part of the prduct view, which displays the actual data of the product.
 
     This is factored out to be able to better cached and in might in future used
@@ -363,38 +469,90 @@ def product_inline(request, id, template_name="lfs/catalog/product_inline.html")
 
     properties = []
     variants = []
-    if product.variants_display_type == SELECT:
-        # Get all properties (sorted). We need to traverse through all
-        # property/options to select the options of the current variant.
-        for property in product.get_properties():
+
+    if product.is_product_with_variants():
+        if product.variants_display_type == SELECT:
+            # Get all properties (sorted). We need to traverse through all
+            # property/options to select the options of the current variant.
+            for property in product.get_properties():
+                options = []
+                for property_option in property.options.all():
+                    if variant.has_option(property, property_option):
+                        selected = True
+                    else:
+                        selected = False
+                    options.append({
+                        "id"   : property_option.id,
+                        "name" : property_option.name,
+                        "selected" : selected
+                    })
+                properties.append({
+                    "id" : property.id,
+                    "name" : property.name,
+                    "title" : property.title,
+                    "unit" : property.unit,
+                    "options" : options,
+                })
+        else:
+            properties = product.get_properties()
+            variants = product.get_variants()
+
+    elif product.is_configurable_product:
+        for property in product.get_configurable_properties():
             options = []
+
+            try:
+                ppv = ProductPropertyValue.objects.get(product=product, property=property, type=PROPERTY_VALUE_TYPE_DEFAULT)
+                ppv_value = ppv.value
+            except ProductPropertyValue.DoesNotExist:
+                ppv = None
+                ppv_value = ""
+                
             for property_option in property.options.all():
-                if variant.has_option(property, property_option):
-                    selected = True
+                if ppv_value == str(property_option.id):
+                    selected = True                    
                 else:
                     selected = False
+
                 options.append({
                     "id"   : property_option.id,
                     "name" : property_option.name,
-                    "selected" : selected
+                    "price" : property_option.price,
+                    "selected" : selected,
                 })
+
             properties.append({
+                "obj" : property,
                 "id" : property.id,
                 "name" : property.name,
-                "options" : options
+                "title" : property.title,
+                "unit" : property.unit,
+                "display_price" : property.display_price,
+                "options" : options,
+                "value" : ppv_value,
             })
-    else:
-        properties = product.get_properties()
-        variants = product.get_variants()
 
     # Reviews
+    if product.get_template_name() != None:
+        template_name = product.get_template_name()
+
+    message = request.COOKIES.get("message")
+    if message:
+        message = urllib.unquote(message)
+
+    if product.active_packing_unit:
+        packing_result = calculate_packing(request, id, 1, True)
+    else:
+        packing_result = ""
 
     result = render_to_string(template_name, RequestContext(request, {
         "product" : product,
         "variant" : variant,
         "variants" : variants,
         "product_accessories" : variant.get_accessories(),
-        "properties" : properties
+        "properties" : properties,
+        "message" : message,
+        "packing_result" : packing_result,
     }))
 
     cache.set(cache_key, result)
