@@ -13,7 +13,9 @@ from django.utils.translation import ugettext_lazy as _
 
 # lfs imports
 import lfs.core.utils
+import lfs.discounts.utils
 import lfs.order.utils
+import lfs.payment.settings
 import lfs.payment.utils
 import lfs.shipping.utils
 import lfs.voucher.utils
@@ -129,6 +131,11 @@ def cart_inline(request, template_name="lfs/checkout/checkout_cart_inline.html")
     cart_price = cart_costs["price"] + shipping_costs["price"] + payment_costs["price"]
     cart_tax = cart_costs["tax"] + shipping_costs["tax"] + payment_costs["tax"]
 
+    discounts = lfs.discounts.utils.get_valid_discounts(request)
+    for discount in discounts:
+        cart_price = cart_price - discount["price"]
+        cart_tax = cart_tax - discount["tax"]
+
     # Voucher
     try:
         voucher_number = lfs.voucher.utils.get_current_voucher_number(request)
@@ -156,6 +163,7 @@ def cart_inline(request, template_name="lfs/checkout/checkout_cart_inline.html")
         "cart_price" : cart_price,
         "cart_tax" : cart_tax,
         "display_voucher" : display_voucher,
+        "discounts" : discounts,
         "voucher_value" : voucher_value,
         "voucher_tax" : voucher_tax,
         "shipping_price" : shipping_costs["price"],
@@ -180,7 +188,17 @@ def one_page_checkout(request, checkout_form = OnePageCheckoutForm,
     customer = customer_utils.get_or_create_customer(request)
     if request.method == "POST":
         form = checkout_form(request.POST)
-        if form.is_valid():
+
+        toc = True
+
+        if shop.confirm_toc:
+            if not request.POST.has_key("confirm_toc"):
+                toc = False
+                if form._errors is None:
+                    form._errors = {}
+                form._errors["confirm_toc"] = _(u"Please confirm our terms and conditions")
+
+        if toc and form.is_valid():
             # Create or update invoice address
             if customer.selected_invoice_address is None:
                 invoice_address = Address.objects.create(
@@ -193,6 +211,7 @@ def one_page_checkout(request, checkout_form = OnePageCheckoutForm,
                     country_id = form.cleaned_data.get("invoice_country"),
                     phone = form.cleaned_data.get("invoice_phone"),
                     email = form.cleaned_data.get("invoice_email"),
+                    customer = customer,
                 )
                 customer.selected_invoice_address = invoice_address
             else:
@@ -206,6 +225,7 @@ def one_page_checkout(request, checkout_form = OnePageCheckoutForm,
                 selected_invoice_address.country_id = form.cleaned_data.get("invoice_country")
                 selected_invoice_address.phone = form.cleaned_data.get("invoice_phone")
                 selected_invoice_address.email = form.cleaned_data.get("invoice_email")
+                selected_invoice_address.customer = customer
                 selected_invoice_address.save()
 
             # If the shipping address differs from invoice firstname we create
@@ -222,6 +242,7 @@ def one_page_checkout(request, checkout_form = OnePageCheckoutForm,
                         country_id = form.cleaned_data.get("shipping_country"),
                         phone = form.cleaned_data.get("shipping_phone"),
                         email = form.cleaned_data.get("shipping_email"),
+                        customer = customer,
                     )
                     customer.selected_shipping_address = shipping_address
                 else:
@@ -234,12 +255,12 @@ def one_page_checkout(request, checkout_form = OnePageCheckoutForm,
                     selected_shipping_address.city = form.cleaned_data.get("shipping_city")
                     selected_shipping_address.country_id = form.cleaned_data.get("shipping_country")
                     selected_shipping_address.phone = form.cleaned_data.get("shipping_phone")
+                    selected_shipping_address.customer = customer
                     selected_shipping_address.save()
 
             # Payment method
             customer.selected_payment_method_id = request.POST.get("payment_method")
 
-            # 1 = Direct Debit
             if int(form.data.get("payment_method")) == DIRECT_DEBIT:
                 bank_account = BankAccount.objects.create(
                     account_number = form.cleaned_data.get("account_number"),
@@ -256,22 +277,13 @@ def one_page_checkout(request, checkout_form = OnePageCheckoutForm,
             # process the payment method ...
             result = lfs.payment.utils.process_payment(request)
 
-            payment_method = lfs.payment.utils.get_selected_payment_method(request)
-
-            # Only if the payment is succesful we create the order out of the
-            # cart.
-            if result.get("success") == True:
-                order = lfs.order.utils.add_order(request)
-
-                # TODO: Get rid of these payment specific payment stuff. This
-                # should be within payment utils.
-                if payment_method.id == PAYPAL and settings.LFS_PAYPAL_REDIRECT:
-                    return HttpResponseRedirect(order.get_pay_link())
-                else:
-                    return HttpResponseRedirect(result.get("next-url"))
+            next_url = None
+            if result["accepted"] == True:
+                return HttpResponseRedirect(
+                    result.get("next-url", reverse("lfs_thank_you")))
             else:
                 if result.has_key("message"):
-                    form._errors[result.get("message-key")] = result.get("message")
+                    form._errors[result.get("message-position")] = result.get("message")
 
         else: # form is not valid
             # Create or update invoice address
@@ -439,15 +451,8 @@ def payment_inline(request, form, template_name="lfs/checkout/payment_inline.htm
     Passing the form to be able to display payment forms within the several
     payment methods, e.g. credit card form.
     """
-    # Payment
-    try:
-        selected_payment_method_id = request.POST.get("payment_method")
-        selected_payment_method = PaymentMethod.objects.get(pk=selected_payment_method_id)
-    except PaymentMethod.DoesNotExist:
-        selected_payment_method = lfs.payment.utils.get_selected_payment_method(request)
-
+    selected_payment_method = lfs.payment.utils.get_selected_payment_method(request)
     valid_payment_methods = lfs.payment.utils.get_valid_payment_methods(request)
-    display_bank_account = DIRECT_DEBIT in [m.id for m in valid_payment_methods]
 
     return render_to_string(template_name, RequestContext(request, {
         "payment_methods" : valid_payment_methods,
@@ -529,4 +534,4 @@ def _save_customer(request, customer):
 
     lfs.shipping.utils.update_to_valid_shipping_method(request, customer)
     lfs.payment.utils.update_to_valid_payment_method(request, customer)
-    customer.save()
\ No newline at end of file
+    customer.save()
