@@ -1,12 +1,8 @@
 from django.conf.urls.defaults import *
 from django.views.generic.simple import direct_to_template
 
-urlpatterns = patterns('django.views.generic.simple',
-    (r'^products-new', 'direct_to_template', { 'template': 'manage/new/product.html' }),
-)
-
 # General
-urlpatterns += patterns('lfs.manage.views',
+urlpatterns = patterns('lfs.manage.views',
     url(r'^$', "dashboard", name="lfs_manage_dashboard"),
 )
 
@@ -17,6 +13,18 @@ urlpatterns += patterns('lfs.manage.views.delivery_times',
     url(r'^delete-delivery-time/(?P<id>\d*)$', "delete_delivery_time", name="lfs_delete_delivery_time"),
 )
 
+# Manufacturer
+urlpatterns += patterns('lfs.manage.views.manufacturer',
+    url(r'^manage/manufacturer-dispatcher$', "manufacturer_dispatcher", name="lfs_manufacturer_dispatcher"),
+    url(r'^manage/manufacturer/(?P<manufacturer_id>\d*)$', "manage_manufacturer", name="lfs_manufacturer"),
+    url(r'^manage/update-manufacturer-data/(?P<manufacturer_id>\d*)$', "update_data", name="lfs_manufacturer_update_manufacturer_data"),
+    url(r'^manage/add-manufacturer$', "add_manufacturer", name="lfs_manufacturer_add_manufacturer"),
+    url(r'^manage/delete-manufacturer/(?P<manufacturer_id>\d*)$', "delete_manufacturer", name="lfs_manufacturer_delete_manufacturer"),
+    url(r'^manage/edit-category-manufacturer/(?P<manufacturer_id>\d*)/(?P<category_id>\d*)$', "edit_category", name="lfs_manufacturer_edit_category"),
+    url(r'^manage/edit-product-manufacturer/(?P<manufacturer_id>\d*)/(?P<product_id>\d*)$', "edit_product", name="lfs_manufacturer_edit_product"),
+    url(r'^manage/category-state-manufacturer/(?P<manufacturer_id>\d*)/(?P<category_id>\d*)$', "category_state", name="lfs_manufacturer_category_state"),
+    url(r'^manage/manufacturer-inline/(?P<manufacturer_id>\d*)/(?P<category_id>\d*)$', "manufacturer_inline", name="lfs_manufacturer_inline"),
+)
 
 # Marketing
 urlpatterns += patterns('lfs.manage.views.marketing',
@@ -104,6 +112,7 @@ urlpatterns += patterns('lfs.manage.views.product.variants',
     url(r'^update-variants/(?P<product_id>\d*)$', "update_variants", name="lfs_manage_update_variants"),
     url(r'^add-variants/(?P<product_id>\d*)$', "add_variants", name="lfs_add_variants"),
     url(r'^edit-sub-type/(?P<product_id>\d*)$', "edit_sub_type", name="lfs_edit_sub_type"),
+    url(r'^update-default-variant/(?P<product_id>\d*)$', "update_default_variant", name="lfs_update_default_variant"),
 )
 
 # Property Groups
@@ -141,6 +150,11 @@ urlpatterns += patterns('lfs.manage.views.properties',
     url(r'^save-shop-property-step-type/(?P<property_id>\d*)', "save_step_type", name="lfs_save_shop_property_step_type"),
     url(r'^delete-shop-property-option/(?P<id>\d*)', "delete_option", name="lfs_delete_shop_property_option"),
     url(r'^delete-shop-property-step/(?P<id>\d*)', "delete_step", name="lfs_delete_shop_property_step"),
+
+    url(r'^save-number-field-validators/(?P<property_id>\d*)', "save_number_field_validators", name="lfs_save_number_field_validators"),
+    url(r'^save-select-field/(?P<property_id>\d*)', "save_select_field", name="lfs_save_select_field"),
+
+
 )
 
 # Product properties
@@ -192,6 +206,7 @@ urlpatterns += patterns('lfs.manage.views.categories',
     url(r'^delete-category/(?P<id>[-\w]*)$', "delete_category", name="lfs_delete_category"),
     url(r'^products-inline/(?P<category_id>\d*)$', "products_inline", name="lfs_manage_category_products_inline"),
     url(r'^edit-category-data/(?P<category_id>\d*)$', "edit_category_data", name="lfs_manage_category_edit_data"),
+    url(r'^edit-category-view/(?P<category_id>\d*)$', "category_view", name="lfs_manage_category_view"),
     url(r'^selected-products/(?P<category_id>\d*)$', "selected_products", name="lfs_selected_products"),
     url(r'^load-products-tab/(?P<category_id>\d*)$', "products_tab", name="lfs_load_products_tab"),
 )
@@ -242,6 +257,16 @@ urlpatterns += patterns('lfs.manage.views',
     url(r'^save-shipping-method-criteria/(?P<shipping_method_id>\d*)$', "save_shipping_method_criteria", name="lfs_manage_save_shipping_method_criteria"),
 )
 
+# Discounts
+urlpatterns += patterns('lfs.manage.views.discounts',
+    url(r'^discounts$', "manage_discounts", name="lfs_manage_discounts"),
+    url(r'^discount/(?P<id>\d*)$', "manage_discount", name="lfs_manage_discount"),
+    url(r'^add-discount', "add_discount", name="lfs_manage_add_discount"),
+    url(r'^save-discount-data/(?P<id>\d*)$', "save_discount_data", name="lfs_manage_save_discount_data"),
+    url(r'^delete-discount/(?P<id>\d*)$', "delete_discount", name="lfs_manage_delete_discount"),
+    url(r'^save-discount-criteria/(?P<id>\d*)$', "save_discount_criteria", name="lfs_manage_save_discount_criteria"),
+)
+
 # Pages
 urlpatterns += patterns('lfs.manage.views.page',
     url(r'^add-page$', "add_page", name="lfs_add_page"),
@@ -292,6 +317,9 @@ urlpatterns += patterns('lfs.manage.views.static_blocks',
     url(r'^preview-static-block/(?P<id>\d*)$', "preview_static_block", name="lfs_preview_static_block"),
     url(r'^manage-static-blocks$', "manage_static_blocks", name="lfs_manage_static_blocks"),
     url(r'^manage-static-block/(?P<id>\d*)$', "manage_static_block", name="lfs_manage_static_block"),
+    url(r'^add_files/(?P<id>[-\w]*)', "add_files", name="lfs_add_files_to_static_block"),
+    url(r'^update_files/(?P<id>[-\w]*)', "update_files", name="lfs_manage_update_files_sb"),
+    url(r'^reload_files/(?P<id>[-\w]*)', "reload_files", name="lfs_reload_files"),
 )
 
 # Reviews
@@ -344,4 +372,5 @@ urlpatterns += patterns('lfs.manage.views.utils',
     url(r'^clear-cache$', "clear_cache", name="lfs_clear_cache"),
     url(r'^set-category-levels$', "set_category_levels", name="lfs_set_category_levels"),
     url(r'^update-effective-price$', "update_effective_price", name="lfs_update_effective_price"),
-)
\ No newline at end of file
+    url(r'^reindex-topseller$', "reindex_topseller", name="lfs_reindex_topseller"),
+)
