@@ -18,13 +18,14 @@ import lfs.core.utils
 from lfs.caching.utils import lfs_get_object_or_404
 from lfs.catalog.models import Category
 from lfs.catalog.models import Product
-from lfs.catalog.settings import VARIANT, PRODUCT_TYPE_FORM_CHOICES
+from lfs.catalog.settings import VARIANT, PRODUCT_TYPE_FORM_CHOICES, PRODUCT_TEMPLATES
 from lfs.core.utils import LazyEncoder
 from lfs.manage.views.product.images import manage_images
 from lfs.manage.views.product.seo import manage_seo
 from lfs.manage.views.product.properties import manage_properties
 from lfs.manage.views.lfs_portlets import portlets_inline
 
+from lfs.utils.widgets import SelectImage
 # Forms
 class ProductSubTypeForm(ModelForm):
     """Form to change the sub type.
@@ -40,20 +41,52 @@ class ProductSubTypeForm(ModelForm):
 class ProductDataForm(ModelForm):
     """Form to add and edit master data of a product.
     """
+    def __init__(self,*args, **kwargs):
+        super(ProductDataForm, self).__init__(*args, **kwargs)
+        self.fields["template"].widget = SelectImage(choices=PRODUCT_TEMPLATES)
+
     class Meta:
         model = Product
-        fields = ("active", "name", "slug", "sku", "price", "tax",
-            "short_description", "description", "for_sale", "for_sale_price")
+        fields = ("active", "name", "slug", "sku", "sku_manufacturer", "price", "tax",
+            "short_description", "description", "for_sale", "for_sale_price", "static_block", "template",
+            "active_price_calculation", "price_calculation", "price_unit", "unit")
+
+    def clean(self):
+        super(ProductDataForm, self).clean()
+        if self.instance:
+            redirect_to = self.data.get("redirect_to", "")
+            if redirect_to != "":
+                lfs.core.utils.set_redirect_for(self.instance.get_absolute_url(), redirect_to)
+            else:
+                lfs.core.utils.remove_redirect_for(self.instance.get_absolute_url())
+
+        return self.cleaned_data
 
 class VariantDataForm(ModelForm):
     """Form to add and edit master data of a variant.
     """
+    def __init__(self,*args, **kwargs):
+        super(VariantDataForm, self).__init__(*args, **kwargs)
+        self.fields["template"].widget = SelectImage(choices=PRODUCT_TEMPLATES)
+
     class Meta:
         model = Product
-        fields = ("active", "active_name", "name", "slug", "active_sku", "sku",
+        fields = ("active", "active_name", "name", "slug", "active_sku", "sku", "sku_manufacturer",
             "active_price", "price", "active_short_description", "short_description", "active_description",
             "description", "for_sale", "for_sale_price", "active_for_sale", "active_for_sale_price",
-            "active_related_products")
+            "active_related_products", "active_static_block", "static_block", "template")
+
+    def clean(self):
+        """
+        """
+        if self.instance:
+            redirect_to = self.data.get("redirect_to", "")
+            if redirect_to != "":
+                lfs.core.utils.set_redirect_for(self.instance.get_absolute_url(), redirect_to)
+            else:
+                lfs.core.utils.remove_redirect_for(self.instance.get_absolute_url())
+
+        return self.cleaned_data
 
 class ProductStockForm(ModelForm):
     """Form to add and edit stock data of a product.
@@ -62,18 +95,19 @@ class ProductStockForm(ModelForm):
         model = Product
         fields = ("weight", "width", "height", "length", "manage_stock_amount",
                   "stock_amount", "manual_delivery_time", "delivery_time",
-                  "deliverable", "order_time", "ordered_at", "active_dimensions")
+                  "deliverable", "order_time", "ordered_at", "active_dimensions",
+                  "packing_unit", "packing_unit_unit", "active_packing_unit")
 
     def __init__(self, *args, **kwargs):
         super(ProductStockForm, self).__init__(*args, **kwargs)
         self.fields["ordered_at"].widget = widgets.AdminDateWidget()
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def manage_product(request, product_id, template_name="manage/product/product.html"):
     """Displays the whole manage/edit form for the product with the passed id.
     """
     # NOTE: For any reason the script from swfupload (see product/images.html)
-    # calls this method (I have no idea how and why). It calls it without a 
+    # calls this method (I have no idea how and why). It calls it without a
     # product id so we have to take care of it here as a workaround.
     if not product_id:
         return HttpResponse("")
@@ -102,22 +136,22 @@ def manage_product(request, product_id, template_name="manage/product/product.ht
         "form" : ProductSubTypeForm(instance=product)
     }))
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def stock(request, product_id, template_name="manage/product/stock.html"):
     """Displays and updates product's stock data.
     """
+    # prefix="stock" because <input name="length" doesn't seem to work with IE
     product = lfs_get_object_or_404(Product, pk=product_id)
 
     if request.method == "POST":
-        form = ProductStockForm(instance=product, data=request.POST)
+        form = ProductStockForm(prefix="stock", instance=product, data=request.POST)
         if form.is_valid():
             form.save()
-            form = ProductStockForm(instance=product)
             message = _(u"Product stock data has been saved.")
         else:
             message = _(u"Please correct the indicated errors.")
     else:
-        form = ProductStockForm(instance=product)
+        form = ProductStockForm(prefix="stock", instance=product)
 
     result = render_to_string(template_name, RequestContext(request, {
         "product" : product,
@@ -133,7 +167,7 @@ def stock(request, product_id, template_name="manage/product/stock.html"):
     else:
         return result
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def product_data_form(request, product_id, template_name="manage/product/data.html"):
     """Displays the product master data form within the manage product view.
     """
@@ -147,9 +181,10 @@ def product_data_form(request, product_id, template_name="manage/product/data.ht
     return render_to_string(template_name, RequestContext(request, {
         "product" : product,
         "form" : form,
+        "redirect_to" : lfs.core.utils.get_redirect_for(product.get_absolute_url()),
     }))
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def products(request, template_name="manage/product/products.html"):
     """Displays an overview list of all products.
     """
@@ -164,7 +199,7 @@ def products(request, template_name="manage/product/products.html"):
     }))
 
 # Parts
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def products_inline(request, page, paginator, template_name="manage/product/products_inline.html"):
     """Displays the list of products.
     """
@@ -173,7 +208,7 @@ def products_inline(request, page, paginator, template_name="manage/product/prod
         "paginator" : paginator,
     }))
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def product_filters_inline(request, page, paginator, product_id=0,
     template_name="manage/product/product_filters_inline.html"):
     """
@@ -196,7 +231,7 @@ def product_filters_inline(request, page, paginator, product_id=0,
         "product_id" : product_id,
     }))
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def pages_inline(request, page, paginator, template_name="manage/product/pages_inline.html"):
     """Displays the page navigation.
     """
@@ -205,7 +240,7 @@ def pages_inline(request, page, paginator, template_name="manage/product/pages_i
         "paginator" : paginator,
     }))
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def selectable_products_inline(request, page, paginator, product_id=0, template_name="manage/product/selectable_products_inline.html"):
     """Displays the selectable products for the product view. (Used to switch
     quickly from one product to another.)
@@ -214,7 +249,7 @@ def selectable_products_inline(request, page, paginator, product_id=0, template_
         product_id = int(product_id)
     except TypeError:
         product_id = 0
-        
+
     return render_to_string(template_name, RequestContext(request, {
         "paginator" : paginator,
         "page" : page,
@@ -222,6 +257,7 @@ def selectable_products_inline(request, page, paginator, product_id=0, template_
     }))
 
 # Actions
+@permission_required("core.manage_shop", login_url="/login/")
 def add_product(request, template_name="manage/product/add_product.html"):
     """Shows a simplified product form and adds a new product.
     """
@@ -238,7 +274,7 @@ def add_product(request, template_name="manage/product/add_product.html"):
         "form" : form
     }))
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def change_subtype(request, product_id):
     """Changes the sub type of the product with passed id.
     """
@@ -251,7 +287,7 @@ def change_subtype(request, product_id):
         msg = _(u"Sub type has been changed."),
     )
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def delete_product(request, product_id):
     """Deletes product with passed id.
     """
@@ -261,7 +297,7 @@ def delete_product(request, product_id):
     url = reverse("lfs_manage_product_dispatcher")
     return HttpResponseRedirect(url)
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def edit_product_data(request, product_id, template_name="manage/product/data.html"):
     """Edits the product with given.
     """
@@ -282,24 +318,25 @@ def edit_product_data(request, product_id, template_name="manage/product/data.ht
         else:
             form = ProductDataForm(instance=product)
 
-        message = "Productdata has been saved."
+        message = _(u"Productdata has been saved.")
     else:
-        message = "Please correct the indicated errors."
+        message = _(u"Please correct the indicated errors.")
 
     form_html = render_to_string(template_name, RequestContext(request, {
         "product" : product,
         "form" : form,
+        "redirect_to" : lfs.core.utils.get_redirect_for(product.get_absolute_url()),
     }))
 
     result = simplejson.dumps({
         "selectable_products" : selectable_products_inline(request, page, paginator, product_id),
         "form" : form_html,
         "message" : message,
-    })
+    }, cls = LazyEncoder)
 
     return HttpResponse(result)
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def product_dispatcher(request):
     """Dispatches to the first product. This is called when the shop user clicks
     on the manage products link.
@@ -312,17 +349,17 @@ def product_dispatcher(request):
 
     return HttpResponseRedirect(url)
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def reset_filters(request):
     """Resets all product filters.
     """
     if request.session.has_key("product_filters"):
         del request.session["product_filters"]
-            
+
     products = _get_filtered_products(request)
     paginator = Paginator(products, 20)
     page = paginator.page(request.REQUEST.get("page", 1))
-    
+
     product_id = request.REQUEST.get("product-id", 0)
     html = (
         ("#product-filters", product_filters_inline(request, page, paginator, product_id)),
@@ -336,14 +373,14 @@ def reset_filters(request):
         {"html" : html, "message" : msg, }, cls = LazyEncoder)
     return HttpResponse(result)
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def save_products(request):
     """Saves products with passed ids (by request body).
     """
     products = _get_filtered_products(request)
     paginator = Paginator(products, 20)
     page = paginator.page(request.REQUEST.get("page", 1))
-    
+
     for key, value in request.POST.items():
 
         if key.startswith("id-"):
@@ -393,7 +430,7 @@ def save_products(request):
 
     return HttpResponse(result)
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def set_filters(request):
     """Sets product filters given by passed request.
     """
@@ -428,7 +465,7 @@ def set_filters(request):
 
     return HttpResponse(result)
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def set_products_page(request):
     """Sets the displayed product page.
     """
@@ -445,7 +482,7 @@ def set_products_page(request):
     return HttpResponse(
         simplejson.dumps({ "html" : html }, cls = LazyEncoder))
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def product_by_id(request, product_id):
     """Little helper which returns a product by id. (For the shop customer the
     products are displayed by slug, for the manager by id).
@@ -483,7 +520,6 @@ def _get_filtered_products(request):
     if price.find("-") != -1:
         s, e = price.split("-")
         products = products.filter(price__range = (s, e))
-
     category = product_filters.get("category", "")
     if category == "None":
         products = products.filter(categories__in = []).distinct()
@@ -496,4 +532,4 @@ def _get_filtered_products(request):
 
     products = products.order_by("%s%s" % (product_ordering_order, product_ordering))
 
-    return products
\ No newline at end of file
+    return products
