@@ -23,7 +23,7 @@ from lfs.core.utils import LazyEncoder
 # review imports
 from reviews.models import Review
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def review(request, review_id, template_name="manage/reviews/review.html"):
     """Displays review with provided review id.
     """
@@ -32,6 +32,7 @@ def review(request, review_id, template_name="manage/reviews/review.html"):
         "selectable_reviews_inline" : selectable_reviews_inline(request, review_id, as_string=True),
     }));
 
+@permission_required("core.manage_shop", login_url="/login/")
 def review_inline(request, review_id, as_string=False, template_name="manage/reviews/review_inline.html"):
     """Displays review with provided review id.
     """
@@ -55,7 +56,7 @@ def review_inline(request, review_id, as_string=False, template_name="manage/rev
 
         return HttpResponse(result)
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def reviews(request, template_name="manage/reviews/reviews.html"):
     """Base view to display reviews overview.
     """
@@ -63,7 +64,7 @@ def reviews(request, template_name="manage/reviews/reviews.html"):
         "reviews_inline" : reviews_inline(request, as_string=True),
     }))
 
-@permission_required("manage_shop", login_url="/login/")
+@permission_required("core.manage_shop", login_url="/login/")
 def reviews_inline(request, as_string=False, template_name="manage/reviews/reviews_inline.html"):
     """Displays carts overview.
     """
@@ -97,6 +98,7 @@ def reviews_inline(request, as_string=False, template_name="manage/reviews/revie
 
         return HttpResponse(result)
 
+@permission_required("core.manage_shop", login_url="/login/")
 def selectable_reviews_inline(request, review_id=0, as_string=False,
     template_name="manage/reviews/selectable_reviews_inline.html"):
     """Display selectable reviews.
@@ -127,6 +129,7 @@ def selectable_reviews_inline(request, review_id=0, as_string=False,
 
         return HttpResponse(result)
 
+@permission_required("core.manage_shop", login_url="/login/")
 def set_ordering(request, ordering):
     """Sets review ordering given by passed request.
     """
@@ -155,6 +158,7 @@ def set_ordering(request, ordering):
 
     return HttpResponse(result)
 
+@permission_required("core.manage_shop", login_url="/login/")
 def set_review_filters(request):
     """Sets review filters given by passed request.
     """
@@ -192,6 +196,7 @@ def set_review_filters(request):
 
     return HttpResponse(result)
 
+@permission_required("core.manage_shop", login_url="/login/")
 def reset_review_filters(request):
     """Resets all review filters.
     """
@@ -216,6 +221,7 @@ def reset_review_filters(request):
 
     return HttpResponse(result)
 
+@permission_required("core.manage_shop", login_url="/login/")
 def delete_review(request, review_id):
     """Deletes review with passed review id.
     """
@@ -226,11 +232,10 @@ def delete_review(request, review_id):
     else:
         review.delete()
 
-    response = HttpResponseRedirect(reverse("lfs_manage_reviews"))
-    lfs.core.utils.set_message_to(response, _(u"Review has been deleted."))
-
-    return response
+    return set_message_cookie(
+        reverse("lfs_manage_reviews"), _(u"Review has been deleted."))
 
+@permission_required("core.manage_shop", login_url="/login/")
 def set_state(request, review_id):
     """Sets the state for given review.
     """
@@ -271,7 +276,7 @@ def _get_filtered_reviews(request, review_filters):
     active = review_filters.get("active", "")
     if active != "":
         reviews = reviews.filter(active=active)
-    
+
     # Ordering
     if review_ordering == "product":
         reviews = list(reviews)
@@ -279,8 +284,8 @@ def _get_filtered_reviews(request, review_filters):
             reviews.sort(lambda b, a: cmp(a.content.get_name(), b.content.get_name()))
         else:
             reviews.sort(lambda a, b: cmp(a.content.get_name(), b.content.get_name()))
-            
+
     else:
         reviews = reviews.order_by("%s%s" % (review_ordering_order, review_ordering))
 
-    return reviews
\ No newline at end of file
+    return reviews
