@@ -4,8 +4,20 @@ function popup(url, w, h) {
     w.focus();
 }
 
-$(function() {
+// Update checkout
+var update_checkout = function() {
+    var data = $(".checkout-form").ajaxSubmit({
+        url : $(".checkout-form").attr("data"),
+        "success" : function(data) {
+            var data = JSON.parse(data);
+            $("#cart-inline").html(data["cart"]);
+            $("#shipping-inline").html(data["shipping"]);
+            $("#payment-inline").html(data["payment"]);
+        }
+    });
+}
 
+$(function() {
     // Delay plugin taken from ###############################################
     // http://ihatecode.blogspot.com/2008/04/jquery-time-delay-event-binding-plugin.html
 
@@ -49,15 +61,6 @@ $(function() {
         $("#id_score").val($(this).attr("data"));
     });
 
-    // General ################################################################
-    // $().ajaxSend(function(r,s){
-    //     $("#spinner").show()
-    // });
-    //
-    // $().ajaxStop(function(r,s){
-    //     $("#spinner").hide()
-    // });
-
     // Product ################################################################
 
     $("a.product-image").lightBox({
@@ -111,6 +114,40 @@ $(function() {
         });
     });
 
+    $(".product-quantity").attr("autocomplete", "off");
+
+    $(".product-quantity").livequery("keyup", function() {
+        var url = $("#packing-url").attr("data")
+        if (url) {
+            $("#product-form").ajaxSubmit({
+                url : url,
+                success : function(data) {
+                    var data = JSON.parse(data);
+                    $(".packing-result").html(data["html"]);
+                }
+            });
+        }
+    });
+
+    $("select.cp-property").livequery("change", function() {
+        $("#product-form").ajaxSubmit({
+            url : $("#cp-url").attr("data"),
+            success : function(data) {
+                var data = JSON.parse(data);
+                $(".standard-price-value").html(data["price"]);
+                $(".for-sale-price-value").html(data["for-sale-price"]);
+                $(".for-sale-standard-price-value").html(data["for-sale-standard-price"]);
+                // $.jGrowl(data["message"]);
+
+                // Re-bind lightbox
+                $("a.product-image").lightBox({
+                    "txtImage" : "Bild",
+                    "txtOf" : " von "
+                });
+            }
+        });
+    });
+
     // Cart ###################################################################
     $(".add-accessory-link").livequery("click", function() {
         var url = $(this).attr("href");
@@ -133,7 +170,10 @@ $(function() {
         $("#cart-form").ajaxSubmit({
             "type" : "post",
             "success" : function(data) {
-                $("#cart-inline").html(data);
+                var data = JSON.parse(data);
+                $("#cart-inline").html(data["html"]);
+                if (data["message"])
+                    $.jGrowl(data["message"]);
             }
         })
     });
@@ -142,7 +182,8 @@ $(function() {
         $("#cart-form").ajaxSubmit({
             "type" : "post",
             "success" : function(data) {
-                $("#cart-inline").html(data);
+                var data = JSON.parse(data);
+                $("#cart-inline").html(data["html"]);
             }
         })
     });
@@ -151,7 +192,8 @@ $(function() {
         $("#cart-form").ajaxSubmit({
             "type" : "post",
             "success" : function(data) {
-                $("#cart-inline").html(data);
+                var data = JSON.parse(data);
+                $("#cart-inline").html(data["html"]);
             }
         })
     });
@@ -160,7 +202,8 @@ $(function() {
         $("#cart-form").ajaxSubmit({
             "type" : "post",
             "success" : function(data) {
-                $("#cart-inline").html(data);
+                var data = JSON.parse(data);
+                $("#cart-inline").html(data["html"]);
             }
         })
     });
@@ -180,9 +223,9 @@ $(function() {
                 $("#livesearch-result").hide();
             }
             else {
-                var phrase = $("#search-input").attr("value");
+                var q = $("#search-input").attr("value");
                 var url = $("#search-input").attr("data");
-                $.get(url, {"phrase" : phrase}, function(data) {
+                $.get(url, {"q" : q}, function(data) {
                     data = JSON.parse(data);
                     if (data["state"] == "success") {
                         $("#livesearch-result").html(data["products"]);
@@ -224,14 +267,14 @@ $(function() {
         });
     })
 
-    if ($("#payment-method-6:checked").val() != null) {
+    if ($(".payment-method-type-2:checked").val() != null) {
         $("#credit-card").show();
     }
     else {
         $("#credit-card").hide();
     }
 
-    if ($("#payment-method-1:checked").val() != null) {
+    if ($(".payment-method-type-1:checked").val() != null) {
         $("#bank-account").show();
     }
     else {
@@ -239,13 +282,13 @@ $(function() {
     }
 
     $(".payment-methods").livequery("click", function() {
-        if ($("#payment-method-1:checked").val() != null) {
+        if ($(".payment-method-type-1:checked").val() != null) {
             $("#bank-account").slideDown("fast");
         }
         else {
             $("#bank-account").slideUp("fast");
         }
-        if ($("#payment-method-6:checked").val() != null) {
+        if ($(".payment-method-type-2:checked").val() != null) {
             $('#credit-card').slideDown("fast");
         }
         else {
@@ -253,19 +296,6 @@ $(function() {
         }
     })
 
-    // Update checkout
-    var update_checkout = function() {
-        var data = $(".checkout-form").ajaxSubmit({
-            url : $(".checkout-form").attr("data"),
-            "success" : function(data) {
-                var data = JSON.parse(data);
-                $("#cart-inline").html(data["cart"]);
-                $("#shipping-inline").html(data["shipping"]);
-                $("#payment-inline").html(data["payment"]);
-            }
-        });
-    }
-
     $(".update-checkout").livequery("click", function() {
         update_checkout()
     });
