@@ -1,22 +1,25 @@
 import re
-re_digits_nondigits = re.compile(r'\d+|\D+')    
+re_digits_nondigits = re.compile(r'\d+|\D+')
 
 def parse_properties(request):
-    """Parses the query string for properties and returns them in the format: 
+    """Parses the query string for properties and returns them in the format:
     property_id|option_id
     """
     properties = []
     for property, option_id in request.POST.items():
         if property.startswith("property"):
-            property_id = property.split("_")[1]
-            properties.append("%s|%s" % (property_id, option_id))
-    
-    return properties
+            try:
+                property_id = property.split("_")[1]
+            except IndexError:
+                continue
+            else:
+                properties.append("%s|%s" % (property_id, option_id))
 
+    return properties
 
 def FormatWithCommas(format, value):
     """
-    """    
+    """
     parts = re_digits_nondigits.findall(format % (value,))
     for i in xrange(len(parts)):
         s = parts[i]
@@ -24,9 +27,8 @@ def FormatWithCommas(format, value):
             parts[i] = _commafy(s)
             break
     return ''.join(parts)
-    
-def _commafy(s):
 
+def _commafy(s):
     r = []
     for i, c in enumerate(reversed(s)):
         if i and (not (i % 3)):
